/*
	Ohm's Law - An Ohm's Law Calculator
	Copyright © 2004-2007 Harry Whitfield

	This program is free software; you can redistribute it and/or modify it
	under the terms of the GNU General Public License as published by the
	Free Software Foundation; either version 2 of the License, or (at your
	option) any later version.

	This program is distributed in the hope that it will be useful, but
	WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	General Public License for more details.

	You should have received a copy of the GNU General Public License along
	with this program; if not, write to the Free Software Foundation, Inc.,
	51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
	
	Ohm's Law - version 1.3
	7 August, 2007
	Copyright © 2004-2007 Harry Whitfield
	mailto:g6auc@arrl.net
*/

		include("menu.js");

		var minWidth = 180;
		var midWidth = 310;
		var maxWidth = 565;
		
		var curWidth  = minWidth;
		var userWidth = minWidth;

		var debug = false;
		
		var redButtonWithin = false;
		var amberButtonWithin = false;
		var greenButtonWithin = false;
				
		var hasFocus = false;
		
		var mode = Number(preferences.modePref.value);
		
		var paleGreen = "#CCFFCC";
		var white     = "#FFFFFF";
		
		var modeText = ['Voltage and Current','Voltage and Resistance','Voltage and Power',
						'Current and Resistance','Current and Power','Resistance and Power'];

		var modeValue = [3,5,9,6,10,12];
		var modeIndex = [-1,-1,-1,0,-1,1,3,-1,-1,2,4,-1,5];

		function process()
		{
			var V, C, R, P;
			
			switch (mode)	// P=8, R=4, C=2, V=1
			{
				case 3: V = parseFloat(voltage.data);
						C = parseFloat(current.data);
						resistance.data = V / C;
						power.data      = V * C;
						break;
			
				case 5: V = parseFloat(voltage.data);
						R = parseFloat(resistance.data);
						current.data = V / R;
						power.data   = V * V / R;
						break;
						
				case 6: C = parseFloat(current.data);
						R = parseFloat(resistance.data);
						voltage.data = R * C;
						power.data   = C * C * R;
						break;

				case 9: V = parseFloat(voltage.data);
						P = parseFloat(power.data);
						current.data    = P / V;
						resistance.data = V * V / P;
						break;

				case 10:C = parseFloat(current.data);
						P = parseFloat(power.data);
						voltage.data    = P / C;
						resistance.data = P / (C * C);
						break;
			
				case 12:R = parseFloat(resistance.data);
						P = parseFloat(power.data);
						voltage.data = Math.sqrt(P * R);
						current.data = Math.sqrt(P / R);
						break;

				default:beep();
						break;
			}
		}
		
		function setAmber(signed)
		{
			if (signed)
			{
				amberButton.src = "Resources/amberMinus.png";
			}
			else
			{
				amberButton.src = "Resources/amber.png";
			}
		}

		function normalButtons()
		{
			redButton.src   = "Resources/red.png";
			greenButton.src = "Resources/green.png";
			setAmber(false);
		}

		function activeButtons()
		{
			redButton.src   = "Resources/redCross.png";
			greenButton.src = "Resources/greenPlus.png";
			setAmber(true);
		}

		function focusButtons()
		{
			if (hasFocus)
			{
				redButton.src   = "Resources/red.png";
				greenButton.src = "Resources/green.png";
				setAmber(false);
			}
			else
			{
				redButton.src   = "Resources/grey.png";
				amberButton.src = "Resources/grey.png";
				greenButton.src = "Resources/grey.png";
			}
		}

		function toggleSize()
		{
			//print('main_window.width=' + main_window.width);
			
			if (main_window.width == userWidth)
			{
				setUp(curWidth);
			}
			else
			{
				setUp(userWidth);
			}
		}

		function setUp(width)
		{
			if (debug)
			{
				print('setUp():======== start ========:');
				print('width=' + width);
				print('minWidth=' + minWidth);
				print('maxWidth=' + maxWidth);
			}
			
			if (width < minWidth) { width = minWidth; }
			if (width > maxWidth) { width = maxWidth; }

			main_window.width = width;
			middle.width = width - 40;
			right.hOffset = width - 20;
			
			voltage.width = width - 30;
			current.width = width - 30;
			resistance.width = width - 30;
			power.width = width - 30;
						
			dragbox.hOffset = width - 15;
			
			updateNow();
			
			if (debug)
			{
				print('width=' + width);
		
				print('main_window.width=' + main_window.width);
				print('middle.width=' + middle.width);
				print('right.hOffset=' + right.hOffset);
			
				print('voltage.width=' + voltage.width);
				print('current.width=' + current.width);
				print('resistance.width=' + resistance.width);
				print('power.width=' + power.width);
				
				print('dragbox.hOffset=' + dragbox.hOffset);

				print('setUp():========  end  ========:');
			}

			return width;
		}
		
		function clearData()
		{
			voltage.data = "";
			current.data = "";
			resistance.data = "";
			power.data = "";
		}
		
		function updatePrefs(newMode)
		{
			userWidth = curWidth;
			
			voltage.font = current.font = resistance.font = power.font =  preferences.generalFontPref.value;
			paleGreen = preferences.bgColorPref.value;
			mode = Number(newMode);
			chooseMenu.setTick(modeText[modeIndex[mode]]);
			
			voltage.editable    = Boolean(mode & 1); if (mode & 1) { voltage.bgColor    = paleGreen; } else { voltage.bgColor    = white; }
			current.editable    = Boolean(mode & 2); if (mode & 2) { current.bgColor    = paleGreen; } else { current.bgColor    = white; }
			resistance.editable = Boolean(mode & 4); if (mode & 4) { resistance.bgColor = paleGreen; } else { resistance.bgColor = white; }
			power.editable      = Boolean(mode & 8); if (mode & 8) { power.bgColor      = paleGreen; } else { power.bgColor      = white; }
			
			if (mode & 1)
			{
				voltage.focus();
				voltage.select(0, -1);
			}
			else if (mode & 2)
			{
				current.focus();
				current.select(0, -1);
			}
			else if (mode & 4)
			{
				resistance.focus();
				resistance.select(0, -1);
			}
			else if (mode & 8)
			{
				power.focus();
				power.select(0, -1);
			}

			setAmber(false);
			setUp(curWidth);
		}
		
		function chooseMenuAction()								//	(i, data)	// define the action function for chooseMenu
		{
    		var i = this.i, data = this.data;
    		//print("Index:" + i + " Data:" + data);
    		preferences.modePref.value = String(modeValue[i]);
    		updatePrefs(preferences.modePref.value);
		}

		var menuStringsArray = modeText; 						// define the array of menuStrings
		var selectedString   = modeText[modeIndex[mode]];  		// define the initially selected string, or set to ""
		var menuActionFunction   = chooseMenuAction;  			// define the name of the menuAction function - must be a function
		var menuImage = amberButton;

		var chooseMenu = new Menu(menuImage, menuStringsArray, selectedString, menuActionFunction); // call the menu constructor

		updatePrefs(preferences.modePref.value);
		setUp(userWidth);
		focusWidget();
